@@ -21,7 +21,7 @@ ContextBinder <- R6Class(
 
     check_context = function() {
       if (!is.null(private$data)) {
-        return(invisible(NULL))
+        return(invisible())
       }
       caller <- deparse(rlang::caller_call(2))
       msg <- glue("`{caller}` must be used within a *status setter* method.")
