@@ -1,6 +1,6 @@
 .names_plume <- list_modify(.names, public = list(
-   internals = list(contributor_rank = "contributor_rank")
- ))
+  internals = list(contributor_rank = "contributor_rank")
+))
 
 .symbols <- list(
   affiliation = NULL,
@@ -135,7 +135,7 @@ Plume <- R6Class(
         lifecycle::deprecate_warn("0.2.0", "get_author_list(format)", "get_author_list(suffix)")
         suffix <- format
       }
-      authors <- private$get("literal_name")
+      authors <- private$pull("literal_name")
       if (is_empty(suffix)) {
         out <- authors
       } else {
@@ -345,14 +345,14 @@ Plume <- R6Class(
   )
 )
 
- contribution_items <- function(pars, by_author, alphabetical_order) {
-   data <- dplyr::pick(any_of(c(pars$var, pars$rank)))
-   cols <- c(
-     if (has_name(data, pars$rank)) pars$rank,
-     if (alphabetical_order) pars$var
-   )
-   if (!is.null(cols) && !by_author) {
-     data <- arrange(data, across(any_of(cols)))
-   }
-   data[[pars$var]]
- }
+contribution_items <- function(pars, by_author, alphabetical_order) {
+  data <- dplyr::pick(any_of(c(pars$var, pars$rank)))
+  cols <- c(
+    if (has_name(data, pars$rank)) pars$rank,
+    if (alphabetical_order) pars$var
+  )
+  if (!is.null(cols) && !by_author) {
+    data <- arrange(data, across(any_of(cols)))
+  }
+  data[[pars$var]]
+}
